/*
 *    driver_FDC.h - generic FDC driver for WD279x (Z80)
 *
 *    Copyright (c) 2012 by Michal Hucik <http://www.ordoz.com>
 *
 *    Thies program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    driver_FDC is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with driver_FDC; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


#ifndef _driver_FDC
#define _driver_FDC

/* ID mechaniky */
typedef enum {
    FDC_DRIVE0	= 0x00,
    FDC_DRIVE1,
    FDC_DRIVE2,
    FDC_DRIVE3
} FDC_DRIVE_ID;


typedef unsigned char FDC_DRIVE_PARAM;


/* definice parametru media - vastavuje se v FDC_DRIVE_PARAM */
#define FDC_SECTOR_SIZE_128	0x00
#define FDC_SECTOR_SIZE_256	0x01
#define FDC_SECTOR_SIZE_512	0x02
#define FDC_SECTOR_SIZE_1024	0x03
#define FDC_MEDIUM_SIDES1	( 0 << 2 )
#define FDC_MEDIUM_SIDES2	( 1 << 2 )
#define FDC_MEDIUM_NOT_CPL	( 0 << 3 )
#define FDC_MEDIUM_CPL		( 1 << 3 )
#define FDC_MEDIUM_DD		( 0 << 4 )
#define FDC_MEDIUM_HD		( 1 << 4 )	/* jen u HD ready radice */



/*
 * Konfigurace timingu
 *
*/

extern struct _FDC_Timing_s {
    unsigned int driveOnTime;   /* Prodleva pri roztoceni motoru (500 ms) */
    unsigned char trackTime;    /* Track setting time in (6 ms) */
    unsigned char stepTime;     /* Single step time in (6 ms) */
    unsigned char motorPredef;	/* Vypnuti motoru pokud se FDC nepouziva (128 volani pod IM2, po kterych se motor vypne) */
} _FDC_Timing;
            


typedef enum FDC_RESULT {
    FDC_OK = 0,
    FDC_ERR = -1,
    FDC_WRPRT = -2
};



/* Sluzba cteni sektoru */
extern char FDC_ReadSector (
    FDC_DRIVE_ID d, 			/* id zvolene mechaniky 0 - 3 */
    FDC_DRIVE_PARAM p, 			/* parametry media */
    unsigned char log_track,		/* logicka stopa */
    unsigned char phy_sector,		/* fyzicky sektor */
    void* dma				/* adresa dat */
);


/* Sluzba zapis sektoru */
extern char FDC_WriteSector (
    FDC_DRIVE_ID, 			/* id zvolene mechaniky 0 - 3 */
    FDC_DRIVE_PARAM, 			/* parametry media */
    unsigned char log_track,		/* logicka stopa */
    unsigned char phy_sector,		/* fyzicky sektor */
    void* dma				/* adresa dat */
);

/* Sluzba, ktera pod IM2 obsluhuje citac pro prechod mechaniky do stand-by */
extern void FDC_IM2_service ( void );


/* nasilne zastaveni motoru */
extern void FDC_ForceMotorOff ( void );


#endif
